version 11
set more on
log using 7.6.Framingham.ClassVersion.log, replace
*  7.6.Framingham.ClassVersion.log    
*
*  Proportional hazards regression analysis of the effect of gender and 
*  baseline diastolic blood pressure (DBP) on coronary heart disease (CHD)
*  adjusted for age, body mass index (BMI) and serum cholesterol (SCL)
*  (Levy 1999).
*  
use C:\WDDtext\2.20.Framingham.dta, clear
*
*  Univariate analysis of the effect of DBP on CHD
*
histogram dbp, bin(50) frequency ylabel(0(100)500, angle(0)) ytick(0(50)500) ///
    xlabel(40(20)140) xtick(40(10)140) ytitle("Number of Study Subjects")
more
generate dbpgr = recode(dbp,60,70,80,90,100,110,111)
tabulate dbpgr chdfate
label define dbp 60  "DBP <=  60"      70  "60 < DBP <= 70"         ///
		 90  "80 < DBP <= 90"  80  "70 < DBP <= 80"	    ///
		 100 "90 < DBP <= 100" 110 "100 < DBP <= 110" 111 "110 < DBP"
label variable dbpgr "DBP level" 
label values dbpgr dbp
generate time= followup/365.25
label variable time "Follow-up in Years"
stset time, failure(chdfate)
sts graph, by(dbpgr) ytitle(Proportion Without CHD)  			///
   ylabel(0(.2)1, angle(0)) ytick(.0(.1)1) xlabel(0(5)30)	     	/// 
   xtitle("Years of Follow-up") legend(ring(0) position(7) col(1))  	
more
sts test dbpgr
sts test dbpgr if dbpgr ==  60 | dbpgr == 70
sts test dbpgr if dbpgr ==  70 | dbpgr == 80
sts test dbpgr if dbpgr ==  80 | dbpgr == 90
sts test dbpgr if dbpgr ==  90 | dbpgr == 100
sts test dbpgr if dbpgr == 100 | dbpgr == 110
sts test dbpgr if dbpgr == 110 | dbpgr == 111
stcox  i.dbpgr
*
*  Univariate analysis of the effect of gender on CHD
*
sts graph, by(sex) plot1opts(color(blue) lwidth(medthick) )  	///
   plot2opts(color(pink)  lwidth(medthick) )  			///
   ytitle(Cumulative CHD Morbidity)  				///
   xtitle("Years of Follow-up") xlabel(0(5)30) failure		///
   ylabel(0(.1).5, angle(0)) legend(ring(0) position(11) col(1))
more
sts test sex
codebook sex
generate male = sex==1
tabulate male sex
stcox male
*
*  To simplify the analyses let us use fewer DBP groups
*
generate dbpg2 = recode(dbp,60,90,110,111)
tabulate dbpg2
stcox  i.dbpg2
*
*  Store estimates from this model for future likelihood ratio 
*  tests (tests of change in model deviance).
*
estimates store _dbpg2
*
*   How do gender and baseline DBP affect CHD?
*
sort sex
by sex: tabulate dbpg2 chdfate ,row	
*
*  Fit multiplicative model of DBP and gender on risk of CHD
*
stcox  i.dbpg2 male
display 2*(11740.729   -11672.032)
display chi2tail(1, 137.394)
lrtest _dbpg2 .
more
estimates store dbp_male

lincom 90.dbpg2 + male , hr
lincom 110.dbpg2 + male , hr
lincom 111.dbpg2 + male , hr

*
*  Fit model of DBP and gender on risk of CHD using interaction terms
*
stcox  dbpg2##male
lrtest dbp_male .
estimates store dbp_maleInteract
lincom 90.dbpg2  + 1.male +  90.dbpg2#1.male, hr
lincom 110.dbpg2 + 1.male + 110.dbpg2#1.male, hr
lincom 111.dbpg2 + 1.male + 111.dbpg2#1.male, hr
*
*  Adjust model for age, BMI and SCL
*
stcox  dbpg2##male age 
lrtest dbp_maleInteract .
stcox  dbpg2##male age if !missing(bmi) & !missing(scl)
estimates store dbp_maleInteract_age
stcox  dbpg2##male age bmi scl 
lrtest dbp_maleInteract_age .
lincom  90.dbpg2  + 1.male +  90.dbpg2#1.male,  hr
lincom  110.dbpg2 + 1.male + 110.dbpg2#1.male, hr
lincom  111.dbpg2 + 1.male + 111.dbpg2#1.male, hr
log close
