version 8.0
set more on
log using 7.9.4.Framingham.ClassVersion.log, replace
*  7.9.4.Framingham.ClassVersion.log
*
*  Plot Kaplan-Meier cumulative CHD morbidity curves as a function of age.
*  Patients from the Framingham Heart Study enter the analysis when they 
*  reach the age of their baseline exam.
*
use C:\WDDtext\2.20.Framingham.dta, clear
histogram age, bin(39) fraction ylabel(0(.01).04) xlabel(30(5)65)
more
generate time= followup/365.25
label variable time "Follow-up in Years"
generate exitage = age+time
stset exitage, enter(time age) failure(chdfate) 
sts graph, by(sex) failure ytitle(Cumulative CHD Morbidity) xtitle(Age)	///
    ylabel(0(.1).8, angle(0)) legend(ring(0) position(11) col(1))	/// 
    clcolor(blue pink) clwidth(medthick medthick) xlabel(30(10)90) noorigin
more
*
*  Calculate the logrank test corresponding to these morbidity functions
*
sts test sex
*
*  Calculate the relative risk of CHD for men relative to women using 
*  age as the time variable. 
*
generate male = sex==1
stcox male
*
*  Perform hazard regression with time dependent covariates for sex
*
tabulate chdfate male
generate records = 1
replace records= 2 if age< 57 & exitage > 57
expand records
sort id
generate enter = age
replace enter = 57 if id==id[_n-1]
generate exit = exitage
replace exit =57 if id==id[_n+1]
generate fate=chdfate
replace fate= 0 if id==id[_n+1]
tabulate fate male
generate male1 = male*(enter < 57)
generate male2= male*(exit > 57)
tabulate male1 male2
stset exit, id(id) enter(time enter) failure(fate) 
stcox male1 male2
lincom male1 - male2
log close
