version 11.0
log using 8.9.Framingham.log, replace
*  8.9.Framingham.log 
*
*  Convert Framingham survival data setset to person-year data for 
*  Poisson regression analysis.
*
set more on
use  C:\WDDtext\2.20.Framingham.dta, clear
*
*  Convert bmi, scl and dbp into categorical variables that subdivide
*  the data set into quartiles for each of these variables.
*
centile bmi dbp scl, centile(25,50,75)
generate bmi_gr = recode(bmi, 22.8, 25.2, 28, 29)
generate dbp_gr = recode(dbp, 74,80,90,91)
generate scl_gr = recode(scl, 197, 225, 255, 256)
*
*  Calculate years of follow-up for each patient.
*  Round to nearest year for censored patients.
*  Round up to next year when patients exit with CHD
*
generate years = int(followup/365.25) + 1 if chdfate
replace years = round(followup/365.25, 1) if ~chdfate
table sex dbp_gr, contents(sum years) row col
table sex dbp_gr, contents(sum chdfate) row col
generate age_in = age
generate exit = age + years
summarize age_in exit
more
*
*  Transform data set so that there is one record per patient-year of 
*  follow-up.  Define age_now to be the patient's age in each record.
*
stset exit, id(id) enter(time age_in) failure(chdfate)
stsplit age_now, at(30(1)94)
list id age_in years exit age_now  in 278/282
generate age_gr = recode(age_now, 45,50,55,60,65,70,75,80,81)
label define age 45 "<= 45" 50 "45-50" 55 "50-55" 60 "55-60" 65 ///
    "60-65" 70 "65-70" 75 "70-75" 80 "75-80" 81 "> 80"
label values age_gr age
sort sex bmi_gr scl_gr dbp_gr age_gr
*
*  Combine records with identical values of 
*  sex bmi_gr scl_gr dbp_gr and age_gr.
*
collapse (count) pt_yrs=age_in (sum) chd_cnt=chdfate, by(sex bmi_gr scl_gr dbp_gr age_gr)
list sex bmi_gr scl_gr dbp_gr age_gr pt_yrs chd_cnt in 310/315, nodisplay
table sex dbp_gr, contents(sum pt_yrs) row col
table sex dbp_gr, contents(sum chd_cnt) row col
generate male = sex == 1
display _N
save  8.12.Framingham.dta, replace
log close

 