log using  FramSBPbmiMulti.log, replace
*  FramSBPbmiMulti.log
*
*  Framingham data set: Multiple regression analysis of the effect of bmi on
*  sbp (Levy 1999).
*
set more on
use "2.20.Framingham.dta", clear
regress sbp bmi
scatter sbp  bmi, msymbol(Oh)						///
   || lfit sbp bmi, ytitle(Systolic Blood Pressure)			
more
regress sbp age
scatter sbp  age, msymbol(Oh)						///
   || lfit sbp age, ytitle(Systolic Blood Pressure)			
more
regress sbp scl
scatter sbp  scl, msymbol(Oh)						///
   || lfit sbp scl, ytitle(Systolic Blood Pressure)			
more
graph matrix sbp bmi age scl if month==1 & sex==2   , msymbol(oh)
more
*
*  Use multiple regression models with interaction terms to analyze
*  the effects of sbp, bmi, age and scl on sbp.
*
generate woman = sex -1
label define truth 0 "False" 1 "True"
label values woman truth
generate agewoman = age*woman
generate bmiwoman = bmi*woman
generate sclwoman = scl*woman
regress sbp bmi age scl woman bmiwoman agewoman sclwoman
regress sbp bmi age scl woman bmiwoman agewoman 
regress sbp bmi age scl woman  agewoman
*
*  Fit a model of sbp against bmi age scl and sex with
*  interaction terms.  The variables woman, bmiwoman,
*  agewoman, and sclwoman have been previously defined.
*
stepwise, pe(.1): regress sbp bmi  age scl woman bmiwoman agewoman sclwoman
more
stepwise, pr(.1): regress sbp bmi  age scl woman bmiwoman agewoman sclwoman  
more
predict yhat, xb
predict res, rstudent
lowess res yhat,  bwidth(0.2) msymbol(oh) color(gs10) lwidth(thick)     ///
    yline(-1.96 0 1.96) ylabel(-2 (2) 6) ytick(-2 (1) 6) 		///
    xlabel(100 (20) 180) xtitle(Expected SBP)
more
*
*  Illustrate influence of individual data points on
*  the parameter estimates of linear regression.
*
drop res
keep if id > 2000 & id <= 2050
regress sbp bmi age scl woman agewoman, level(50)
predict res, rstudent
predict cook, cooksd
label variable res "Studentized Residual"
label variable cook "Cook's Distance"
scatter cook res, ylabel(0 (.1) .5) xlabel(-2 (1) 5)
list cook res id bmi sbp if res > 2
regress  sbp bmi age scl woman agewoman if id ~= 2049, level(50)
log close
