version 10.0
log using lymphoma.log, replace
*  Lymphoma.log
*
*  Plot Kaplan-Meier Survival curves of lymphoma patients by
*  stage of tumor. 
*
*  See Armitage et al. 2002, Table 17.3.
*      McKelvey et al., 1976.
*
set more on
use  lymphoma.dta, clear
list  in 1/7
codebook fate
stset time, failure (fate)
sts graph, by(stage) ytitle(Probability of Survival)
more
sts graph, by(stage) ytitle(Cumulative Mortality) failure
more
*
*  List survival statistics
*
sts list, by(stage)
sts list, by(stage) at (30 40 50)
sts list, by(stage) at (30 40 50) failure
label define stage 3 "Stage 3" 4 "Stage 4"
label values stage stage
*
*  Kaplan-Meier survival curves by stage with 95% CIs
*
sts graph, by(stage)   ci censored(single) separate 	///
    xlabel(0 (50) 350) xmtick(0 (25) 350)  		///
    byopts(title(, size(0)) legend(off))		///
    ytitle(Probability of Survival)               	///
    ylabel(0 (.1) 1, angle(0)) ciopts(color(yellow))    ///
    xtitle(Days Since Recruitment)  ymtick(0 (.05) 1)    
more
*
*  Kaplan-Meier morbidity curves by stage with risk table
*
sts graph, by(stage)  failure 				///
    risktable(,order(2 "Stage 4" 1 "Stage 3"))		///
    ytitle(Cumulative Mortality) 			///
    xlabel(0 (50) 350) xmtick(0 (25) 350)  		///
    ylabel(0 (.1) .8, angle(0)) 			///
    xtitle(Days Since Recruitment)  ymtick(0 (.05) .8) 	///
    title(" ",size(0)) legend(ring(0) cols(1) 		///
       position(11) order(2 "Stage 4" 1 "Stage 3")) 	 

*
*  Perform log-rank test to compare stage 3 and 4 survival
*
sts test stage
tabulate stage fate, exact
*
*  Perform proportional hazards regression analysis of
*  lymphoma patients by stage of tumor.
*
stcox stage
stcox stage, nohr
log close
