version 8.0
set more on
log using SepsisSplineCheck.log, replace
*  SepsisSplineCheck.do
*
*  Logistic regression of mortality against APACHE score in
*  in the Ibuprofen in Sepsis Study using restricted cubic splines.  
*
use C:\WDDtext\4.18.Sepsis.dta, clear

generate p = deaths/patients
generate obs_logodds = logit(p) if p ~=0 & p ~= 1
*
*  Regress deaths against apache using simple logistic regression
*
glm deaths apache, family(binomial patients) link(logit)
predict logodds, xb
*
*  Calculate 95% confidence region for logodds
*
predict stderr, stdp
generate lodds_lb = logodds - 1.96*stderr
generate lodds_ub = logodds + 1.96*stderr
*
*  Graph observed logodds with regression line & confidence region
*
twoway rarea lodds_lb lodds_ub apache,  bcolor(yellow)			///
    || line logodds apache 						///
    || scatter obs_logodds apache, ytitle("Log Odds of Death")		///
    ,  legend(order(2 "Simple log odds" 3 "Observed log odds" 		///
            1 "95% CI") rows(1))
more
*
*  Calculate rc_spline covariates with 3 knots
*
mkspline _Sapache=apache [weight=patients], nknots(3) cubic displayknots
*
*  Regress deaths against spline covariates
*
glm deaths _S*, family(binomial patients) link(logit)
predict logodds3, xb
line logodds apache,  lwidth(thick) color(blue)			///
    || line logodds3 apache,  lwidth(thick) color(red)			///
    || scatter obs_logodds apache, ytitle("Log Odds of Death")		///
    ,  legend(order(1 "Simple log odds" 2 "Spline log odds" 		///
            3 "Observed log odds") rows(1))
more
predict e_deaths, mu
generate prob = e_deaths/patients
predict se, stdp
generate lb_logodds3= logodds3-1.96* se
generate ub_logodds3= logodds3+1.96* se
generate ub_prob= exp( ub_logodds3)/(1+exp( ub_logodds3))
generate lb_prob= exp( lb_logodds3)/(1+exp( lb_logodds3))
twoway rarea lb_prob ub_prob apache, bcolor(yellow) 			///
    || line prob apache, color(blue) lwidth(medthick)			///
    || scatter p apache, ytitle("Probability of Death by 30 Days") 	///
    legend(order(2 "Expected mortality rate" 				///
           3 "Observed mortality rate" 1 "95% CI") rows(1)) subtitle(	///
       "Restricted Cubic Spline Model with 3 Knots",ring(0) position(11))
log close
