version 9.0
log using SupportLinearRCS.log, replace
set more on
*  SupportLinearRCS.log
*
*  Draw scatter plots of length-of-stay (LOS) by mean arterial 
*  pressure (MAP) and log LOS by MAP for the SUPPORT Study data.  
*  (Lynn & Knauss, 1990).  
*
use 3.25.2.SUPPORT.dta , replace
scatter los map, symbol(Oh) xlabel(25 (25) 175) xmtick(20 (5) 180)  	///
    ylabel(0(25)225, angle(0)) ymtick(5(5)240) name(g1, replace)
more
scatter los map, symbol(Oh) xlabel(25 (25) 175) xmtick(20 (5) 180)  	///
    yscale(log) ylabel(4(2)10  20(20)100 200, angle(0)) 		///
    ymtick(3(1)9 30(10)90) name(g2, replace)
more
*
*  Regress log LOS against MAP using RCS models with 
*  5 knots at their default locations.  Overlay the expected  
*  log LOS from these models on a scatter plot of log LOS by MAP.
*
mkspline _Smap = map, cubic displayknots
summarize _Smap1 _Smap2 _Smap3 _Smap4
generate log_los = log(los)
regress log_los _S*
test _Smap2  _Smap3 _Smap4
predict y_hat, xb
scatter log_los map, symbol(Oh)  					///
    || line y_hat map, color(red) lwidth(medthick)			///
    , xlabel(25 (25) 175) xmtick(20 (5) 180) 				///
        xline(47 66 78 106 129, lcolor(blue))				///
      ylabel(1.39 "4" 1.79 "6" 2.08 "8" 2.3 "10" 3 "20" 		///
          3.69 "40" 4.09 "60" 4.38 "80" 4.61 "100" 5.3 "200", angle(0)) ///
      ymtick(1.1 1.39 1.61 1.79 1.95 2.08 2.2 3.4 3.91 4.25 4.5) 	///
      ytitle(Length of Stay (days))					///
       legend(order(1 "Observed" 2 "Expected")) name(g3, replace)
more
*
*  Plot expected LOS for 7 knot model together with 95% 
*  confidence bands.  Use the default knot locations.
*
drop _S* y_hat
mkspline _Smap = map, nknots(7) cubic displayknots
regress log_los _S*
predict y_hat, xb
predict se, stdp
generate lb = y_hat - invttail(_N-7, 0.025)*se
generate ub = y_hat + invttail(_N-7, 0.025)*se
twoway rarea lb ub map , color(yellow)  				///
    || scatter log_los map, symbol(Oh) color(blue) 			///
    || line y_hat map, color(red) lwidth(medthick)			///
    , xlabel(25 (25) 175) xmtick(20 (5) 180) 				///
      ylabel(1.39 "4" 1.79 "6" 2.08 "8" 2.3 "10" 3 "20" 		///
          3.69 "40" 4.09 "60" 4.38 "80" 4.61 "100" 5.3 "200", angle(0)) ///
      ymtick(1.1 1.39 1.61 1.79 1.95 2.08 2.2 3.4 3.91 4.25 4.5) 	///
      xline(41 60 69 78 101.3 113 138.1, lcolor(gray))			///
      ytitle(Length of Stay (days)) 					///
      subtitle("Default" "Knot" "Values"				///
          , ring(0) position(10)) legend(off)  	name(g4, replace)  	
more
*
*  Replot 7 knot model with evenly spaced knots.
*
drop _S* se y_hat lb ub
mkspline _Smap = map,  knots(39 56 73 90 107 124 141)	 		///
    cubic displayknots
regress log_los _S*
predict y_hat, xb
predict se, stdp
generate lb = y_hat - invttail(_N-7, 0.025)*se
generate ub = y_hat + invttail(_N-7, 0.025)*se
twoway rarea lb ub map , color(yellow)  				///
    || scatter log_los map, symbol(Oh) color(blue)			///
    || line y_hat map, color(red) lwidth(medthick)			///
    , xlabel(25 (25) 175) xmtick(20 (5) 180) 				///
      xline(39(17)141, lcolor(gray))					///
      ylabel(1.39 "4" 1.79 "6" 2.08 "8" 2.3 "10" 3 "20" 		///
          3.69 "40" 4.09 "60" 4.38 "80" 4.61 "100" 5.3 "200", angle(0))	///
      ymtick(1.1 1.39 1.61 1.79 1.95 2.08 2.2 3.4 3.91 4.25 4.5)	///
      subtitle("Evenly" "Spaced" "Knots", ring(0) position(10)) 	///
      ytitle(Length of Stay (days)) legend(off) name(g5, replace)
more
*
*  Regenerate seven-knot model with default knot values.
*
drop _S* y_hat se lb ub
mkspline _Smap = map, nknots(7) cubic
regress log_los _S*
predict rstudent, rstudent
generate big = abs(rstudent)>2
tabulate big
*
*  Draw a scatter plot of the studentized residuals against MAP
*  Overlay the associated lowess regression curve on this graph.
*
twoway scatter rstudent map, symbol(Oh)    			///
    || lowess rstudent map, lwidth(thick) 			///
    ,  ytitle(Studentized Residual) yline(-2 0 2, lcolor(blue)) ///
       legend(off) name(g6, replace)
more
*
*  Plot expected LOS against MAP on a linear scale.
*  Truncate LOS > 70.
*
predict y_hat, xb
predict se, stdp
generate lb = y_hat - invttail(_N-7, 0.025)*se
generate ub = y_hat + invttail(_N-7, 0.025)*se
generate e_los = exp(y_hat)
generate lb_los = exp(lb)
generate ub_los = exp(ub)
generate truncated_los = los
replace truncated_los = 80 if los > 70
twoway rarea lb_los ub_los map , color(yellow)			///  
    ||  scatter truncated_los map , symbol(Oh) 	color(blue)	///
    || line e_los map, color(red) lwidth(medthick)		///
    || rline lb_los ub_los map , color(yellow) 			///
           lwidth(thin thin) 					///
    , xlabel(25 (25) 175) xmtick(30 (5) 170)       		///
      ylabel(0 (10) 70, angle(0)) ytitle(Length of Stay)  	///
      legend(order(3 "Expected MAP" 				///
          1 "95% Confidence Interval") rows(1)) name(g7, replace)
more
log close
